==> shellcheck-0.7.0-71-x86_64.pkg.tar.xz: usr/share/haskell/register/shellcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ShellCheck
version: 0.7.0
id: ShellCheck-0.7.0-Ey7a3fxltxi6LvaQqK9PVo
key: ShellCheck-0.7.0-Ey7a3fxltxi6LvaQqK9PVo
license: GPL-3.0-only
maintainer: vidar@vidarholen.net
author: Vidar Holen
homepage: https://www.shellcheck.net/
synopsis: Shell script analysis tool
description:
    The goals of ShellCheck are:
    .
    * To point out and clarify typical beginner'\''s syntax issues,
    that causes a shell to give cryptic error messages.
    .
    * To point out and clarify typical intermediate level semantic problems,
    that causes a shell to behave strangely and counter-intuitively.
    .
    * To point out subtle caveats, corner cases and pitfalls, that may cause an
    advanced user'\''s otherwise working script to fail under future circumstances.
category: Static Analysis
abi: 3724ddee762fe71d885c9976ceb70010
exposed: True
exposed-modules:
    ShellCheck.AST ShellCheck.ASTLib ShellCheck.Analytics
    ShellCheck.Analyzer ShellCheck.AnalyzerLib ShellCheck.Checker
    ShellCheck.Checks.Commands ShellCheck.Checks.Custom
    ShellCheck.Checks.ShellSupport ShellCheck.Data ShellCheck.Fixer
    ShellCheck.Formatter.CheckStyle ShellCheck.Formatter.Diff
    ShellCheck.Formatter.Format ShellCheck.Formatter.GCC
    ShellCheck.Formatter.JSON ShellCheck.Formatter.JSON1
    ShellCheck.Formatter.Quiet ShellCheck.Formatter.TTY
    ShellCheck.Interface ShellCheck.Parser ShellCheck.Regex
hidden-modules: Paths_ShellCheck
import-dirs: /usr/lib/ghc-8.6.5/site-local/ShellCheck-0.7.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/ShellCheck-0.7.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/ShellCheck-0.7.0
hs-libraries: HSShellCheck-0.7.0-Ey7a3fxltxi6LvaQqK9PVo
depends:
    Diff-0.4.0-1YYnt5yn1qX2V7iSs37XPT
    QuickCheck-2.13.2-C3chvSwT3GSBClgQ9bo1MW
    aeson-1.4.6.0-53gmO5YtU8gIZiWG8EtnAc array-0.5.3.0 base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1 deepseq-1.4.4.0
    directory-1.3.3.0 filepath-1.4.2.1 mtl-2.2.2 parsec-3.1.13.0
    process-1.6.5.0 regex-tdfa-1.2.3.2-1zrqdepzFAcLwdkKMIY7hi
haddock-interfaces: /usr/share/doc/shellcheck/html/ShellCheck.haddock
haddock-html: /usr/share/doc/shellcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> shellcheck-0.7.0-79-x86_64.pkg.tar.xz: usr/share/haskell/register/shellcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ShellCheck
version: 0.7.0
id: ShellCheck-0.7.0-48yEo7ksoKYAx6esWPYBHF
key: ShellCheck-0.7.0-48yEo7ksoKYAx6esWPYBHF
license: GPL-3.0-only
maintainer: vidar@vidarholen.net
author: Vidar Holen
homepage: https://www.shellcheck.net/
synopsis: Shell script analysis tool
description:
    The goals of ShellCheck are:
    .
    * To point out and clarify typical beginner'\''s syntax issues,
    that causes a shell to give cryptic error messages.
    .
    * To point out and clarify typical intermediate level semantic problems,
    that causes a shell to behave strangely and counter-intuitively.
    .
    * To point out subtle caveats, corner cases and pitfalls, that may cause an
    advanced user'\''s otherwise working script to fail under future circumstances.
category: Static Analysis
abi: 2f616a92a0b3d72f083a2d959d11eb10
exposed: True
exposed-modules:
    ShellCheck.AST ShellCheck.ASTLib ShellCheck.Analytics
    ShellCheck.Analyzer ShellCheck.AnalyzerLib ShellCheck.Checker
    ShellCheck.Checks.Commands ShellCheck.Checks.Custom
    ShellCheck.Checks.ShellSupport ShellCheck.Data ShellCheck.Fixer
    ShellCheck.Formatter.CheckStyle ShellCheck.Formatter.Diff
    ShellCheck.Formatter.Format ShellCheck.Formatter.GCC
    ShellCheck.Formatter.JSON ShellCheck.Formatter.JSON1
    ShellCheck.Formatter.Quiet ShellCheck.Formatter.TTY
    ShellCheck.Interface ShellCheck.Parser ShellCheck.Regex
hidden-modules: Paths_ShellCheck
import-dirs: /usr/lib/ghc-8.6.5/site-local/ShellCheck-0.7.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/ShellCheck-0.7.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/ShellCheck-0.7.0
hs-libraries: HSShellCheck-0.7.0-48yEo7ksoKYAx6esWPYBHF
depends:
    Diff-0.4.0-1YYnt5yn1qX2V7iSs37XPT
    QuickCheck-2.13.2-26sILnMT1dV6Y2IUujSwGD
    aeson-1.4.6.0-IYkWE2kAqOg3BtypRoad0s array-0.5.3.0 base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1 deepseq-1.4.4.0
    directory-1.3.3.0 filepath-1.4.2.1 mtl-2.2.2 parsec-3.1.13.0
    process-1.6.5.0 regex-tdfa-1.2.3.2-1zrqdepzFAcLwdkKMIY7hi
haddock-interfaces: /usr/share/doc/shellcheck/html/ShellCheck.haddock
haddock-html: /usr/share/doc/shellcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
